@@ -23,6 +23,7 @@ from starlite.types import (
     ResponseHeadersMap,
     ResponseType,
     SingleOrList,
+    TypeEncodersMap,
 )
 
 from . import AllowedHostsConfig
@@ -170,6 +171,8 @@ class AppConfig(BaseModel):
     """A list of string tags that will be appended to the schema of all route handlers under the application."""
     template_config: Optional[TemplateConfig]
     """An instance of [TemplateConfig][starlite.config.TemplateConfig]."""
+    type_encoders: Optional[TypeEncodersMap] = None
+    """A mapping of types to callables that transform them into types supported for serialization."""
     websocket_class: Optional[Type[WebSocket]]
     """An optional subclass of [WebSocket][starlite.connection.websocket.WebSocket] to use for websocket connections."""
 
