@@ -5,6 +5,7 @@ from operator import attrgetter
 from typing import (
     TYPE_CHECKING,
     Any,
+    AnyStr,
     Awaitable,
     Callable,
     Dict,
@@ -19,6 +20,7 @@ from typing import (
 
 from pydantic import validate_arguments
 from pydantic_openapi_schema.v3_1_0 import SecurityRequirement
+from typing_extensions import get_args
 
 from starlite.constants import REDIRECT_STATUS_CODES
 from starlite.datastructures import (
@@ -34,6 +36,7 @@ from starlite.datastructures.response_containers import (
     Redirect,
     ResponseContainer,
 )
+from starlite.dto import DTO
 from starlite.enums import HttpMethod, MediaType
 from starlite.exceptions import (
     HTTPException,
@@ -65,8 +68,9 @@ from starlite.types import (
     ResponseCookies,
     ResponseHeadersMap,
     ResponseType,
+    TypeEncodersMap,
 )
-from starlite.utils import Ref, is_async_callable
+from starlite.utils import Ref, annotation_is_iterable_of_type, is_async_callable
 from starlite.utils.predicates import is_class_and_subclass
 from starlite.utils.sync import AsyncCallable
 
@@ -111,6 +115,7 @@ async def _normalize_response_data(data: Any, plugins: List["PluginProtocol"]) -
     Returns:
         Value for the response body
     """
+
     plugin = get_plugin_for_value(value=data, plugins=plugins)
     if not plugin:
         return data
@@ -184,7 +189,9 @@ def _create_data_handler(
     headers: "ResponseHeadersMap",
     media_type: str,
     response_class: "ResponseType",
+    return_annotation: Any,
     status_code: int,
+    type_encoders: Optional[TypeEncodersMap],
 ) -> "AsyncAnyCallable":
     """Create a handler function for arbitrary data."""
     normalized_headers = [
@@ -192,19 +199,16 @@ def _create_data_handler(
     ]
     cookie_headers = [cookie.to_encoded_header() for cookie in cookies if not cookie.documentation_only]
     raw_headers = [*normalized_headers, *cookie_headers]
+    is_dto_annotation = is_class_and_subclass(return_annotation, DTO)
+    is_dto_iterable_annotation = annotation_is_iterable_of_type(return_annotation, DTO)
 
-    async def handler(data: Any, plugins: List["PluginProtocol"], **kwargs: Any) -> "ASGIApp":
-        if isawaitable(data):
-            data = await data
-
-        if plugins:
-            data = await _normalize_response_data(data=data, plugins=plugins)
-
+    async def create_response(data: Any) -> "ASGIApp":
         response = response_class(
             background=background,
             content=data,
             media_type=media_type,
             status_code=status_code,
+            type_encoders=type_encoders,
         )
         response.raw_headers = raw_headers
 
@@ -213,6 +217,24 @@ def _create_data_handler(
 
         return response
 
+    async def handler(data: Any, plugins: List["PluginProtocol"], **kwargs: Any) -> "ASGIApp":
+        if isawaitable(data):
+            data = await data
+
+        if is_dto_annotation and not isinstance(data, DTO):
+            data = return_annotation(**data) if isinstance(data, dict) else return_annotation.from_model_instance(data)
+
+        elif is_dto_iterable_annotation and not isinstance(data[0], DTO):  # pyright: ignore
+            dto_type = cast("Type[DTO]", get_args(return_annotation)[0])
+            data = [
+                dto_type(**datum) if isinstance(datum, dict) else dto_type.from_model_instance(datum) for datum in data
+            ]
+
+        elif plugins and not (is_dto_annotation or is_dto_iterable_annotation):
+            data = await _normalize_response_data(data=data, plugins=plugins)
+
+        return await create_response(data=data)
+
     return handler
 
 
@@ -274,6 +296,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         "deprecated",
         "description",
         "etag",
+        "has_sync_callable",
         "http_methods",
         "include_in_schema",
         "media_type",
@@ -290,7 +313,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         "sync_to_thread",
         "tags",
         "template_name",
-        "has_sync_callable",
+        "type_encoders",
     )
 
     has_sync_callable: bool
@@ -312,7 +335,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         exception_handlers: Optional[ExceptionHandlersMap] = None,
         guards: Optional[List[Guard]] = None,
         http_method: Union[HttpMethod, Method, List[Union[HttpMethod, Method]]],
-        media_type: Union[MediaType, str] = MediaType.JSON,
+        media_type: Optional[Union[MediaType, str]] = None,
         middleware: Optional[List[Middleware]] = None,
         name: Optional[str] = None,
         opt: Optional[Dict[str, Any]] = None,
@@ -334,6 +357,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         security: Optional[List[SecurityRequirement]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
+        type_encoders: Optional["TypeEncodersMap"] = None,
         **kwargs: Any,
     ) -> None:
         """Initialize `HTTPRouteHandler`.
@@ -395,6 +419,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
             security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
             tags: A list of string tags that will be appended to the OpenAPI schema.
+            type_encoders: A mapping of types to callables that transform them into types supported for serialization.
             **kwargs: Any additional kwarg - will be set in the opt dictionary.
         """
         if not http_method:
@@ -422,7 +447,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         self.cache_control = cache_control
         self.cache_key_builder = cache_key_builder
         self.etag = etag
-        self.media_type = media_type
+        self.media_type: Union[MediaType, str] = media_type or ""
         self.response_class = response_class
         self.response_cookies = response_cookies
         self.response_headers = response_headers
@@ -438,6 +463,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         self.response_description = response_description
         self.summary = summary
         self.tags = tags
+        self.type_encoders = type_encoders
         self.security = security
         self.responses = responses
         # memoized attributes, defaulted to Empty
@@ -450,6 +476,15 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         self.fn = Ref["MaybePartial[AnyCallable]"](fn)
         self.signature = Signature.from_callable(fn)
         self._validate_handler_function()
+
+        if not self.media_type:
+            if self.signature.return_annotation in {str, bytes, AnyStr, Redirect, File} or any(
+                is_class_and_subclass(self.signature.return_annotation, t_type) for t_type in (str, bytes)  # type: ignore
+            ):
+                self.media_type = MediaType.TEXT
+            else:
+                self.media_type = MediaType.JSON
+
         return self
 
     def resolve_response_class(self) -> Type["Response"]:
@@ -535,6 +570,18 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
 
         return cast("Optional[AfterResponseHookHandler]", self._resolved_after_response)
 
+    def resolve_type_encoders(self) -> Optional[TypeEncodersMap]:
+        """Resolve `type_encoders` by merging existing `type_encoders` from all layers.
+
+        Returns:
+            A `TypeEncodersMap` to use for this response or `None`
+        """
+        type_encoders: TypeEncodersMap = {}
+        for layer in self.ownership_layers:
+            if layer_type_encoders := layer.type_encoders:
+                type_encoders.update(layer_type_encoders)
+        return type_encoders or None
+
     def resolve_response_handler(
         self,
     ) -> Callable[[Any], Awaitable["ASGIApp"]]:
@@ -558,6 +605,8 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
             response_class = self.resolve_response_class()
             headers = self.resolve_response_headers()
             cookies = self.resolve_response_cookies()
+            type_encoders = self.resolve_type_encoders()
+
             if is_class_and_subclass(self.signature.return_annotation, ResponseContainer):  # type: ignore
                 handler = _create_response_container_handler(
                     after_request=after_request,
@@ -566,13 +615,16 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
                     media_type=media_type,
                     status_code=self.status_code,
                 )
+
             elif is_class_and_subclass(self.signature.return_annotation, Response):
                 handler = _create_response_handler(cookies=cookies, after_request=after_request)
+
             elif is_async_callable(self.signature.return_annotation) or self.signature.return_annotation in {
                 ASGIApp,
                 "ASGIApp",
             }:
                 handler = _create_generic_asgi_response_handler(cookies=cookies, after_request=after_request)
+
             else:
                 handler = _create_data_handler(
                     after_request=after_request,
@@ -581,7 +633,9 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
                     headers=headers,
                     media_type=media_type,
                     response_class=response_class,
+                    return_annotation=self.signature.return_annotation,
                     status_code=self.status_code,
+                    type_encoders=type_encoders,
                 )
 
             self._resolved_response_handler = handler
@@ -673,7 +727,7 @@ class get(HTTPRouteHandler):
         etag: Optional[ETag] = None,
         exception_handlers: Optional[ExceptionHandlersMap] = None,
         guards: Optional[List[Guard]] = None,
-        media_type: Union[MediaType, str] = MediaType.JSON,
+        media_type: Optional[Union[MediaType, str]] = None,
         middleware: Optional[List[Middleware]] = None,
         name: Optional[str] = None,
         opt: Optional[Dict[str, Any]] = None,
@@ -695,6 +749,7 @@ class get(HTTPRouteHandler):
         security: Optional[List[SecurityRequirement]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
+        type_encoders: Optional["TypeEncodersMap"] = None,
         **kwargs: Any,
     ) -> None:
         """Initialize `get`.
@@ -752,6 +807,7 @@ class get(HTTPRouteHandler):
             security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
             tags: A list of string tags that will be appended to the OpenAPI schema.
+                       type_encoders: A mapping of types to callables that transform them into types supported for serialization.
             **kwargs: Any additional kwarg - will be set in the opt dictionary.
         """
         if "http_method" in kwargs:
@@ -792,6 +848,7 @@ class get(HTTPRouteHandler):
             summary=summary,
             sync_to_thread=sync_to_thread,
             tags=tags,
+            type_encoders=type_encoders,
             **kwargs,
         )
 
@@ -818,7 +875,7 @@ class head(HTTPRouteHandler):
         etag: Optional[ETag] = None,
         exception_handlers: Optional[ExceptionHandlersMap] = None,
         guards: Optional[List[Guard]] = None,
-        media_type: Union[MediaType, str] = MediaType.JSON,
+        media_type: Optional[Union[MediaType, str]] = None,
         middleware: Optional[List[Middleware]] = None,
         name: Optional[str] = None,
         opt: Optional[Dict[str, Any]] = None,
@@ -840,6 +897,7 @@ class head(HTTPRouteHandler):
         security: Optional[List[SecurityRequirement]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
+        type_encoders: Optional["TypeEncodersMap"] = None,
         **kwargs: Any,
     ) -> None:
         """Initialize `head`.
@@ -900,6 +958,7 @@ class head(HTTPRouteHandler):
             security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
             tags: A list of string tags that will be appended to the OpenAPI schema.
+            type_encoders: A mapping of types to callables that transform them into types supported for serialization.
             **kwargs: Any additional kwarg - will be set in the opt dictionary.
         """
         if "http_method" in kwargs:
@@ -940,6 +999,7 @@ class head(HTTPRouteHandler):
             summary=summary,
             sync_to_thread=sync_to_thread,
             tags=tags,
+            type_encoders=type_encoders,
             **kwargs,
         )
 
@@ -980,7 +1040,7 @@ class post(HTTPRouteHandler):
         etag: Optional[ETag] = None,
         exception_handlers: Optional[ExceptionHandlersMap] = None,
         guards: Optional[List[Guard]] = None,
-        media_type: Union[MediaType, str] = MediaType.JSON,
+        media_type: Optional[Union[MediaType, str]] = None,
         middleware: Optional[List[Middleware]] = None,
         name: Optional[str] = None,
         opt: Optional[Dict[str, Any]] = None,
@@ -1002,6 +1062,7 @@ class post(HTTPRouteHandler):
         security: Optional[List[SecurityRequirement]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
+        type_encoders: Optional["TypeEncodersMap"] = None,
         **kwargs: Any,
     ) -> None:
         """Initialize `post`
@@ -1059,6 +1120,7 @@ class post(HTTPRouteHandler):
             security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
             tags: A list of string tags that will be appended to the OpenAPI schema.
+            type_encoders: A mapping of types to callables that transform them into types supported for serialization.
             **kwargs: Any additional kwarg - will be set in the opt dictionary.
         """
         if "http_method" in kwargs:
@@ -1098,6 +1160,7 @@ class post(HTTPRouteHandler):
             summary=summary,
             sync_to_thread=sync_to_thread,
             tags=tags,
+            type_encoders=type_encoders,
             **kwargs,
         )
 
@@ -1124,7 +1187,7 @@ class put(HTTPRouteHandler):
         etag: Optional[ETag] = None,
         exception_handlers: Optional[ExceptionHandlersMap] = None,
         guards: Optional[List[Guard]] = None,
-        media_type: Union[MediaType, str] = MediaType.JSON,
+        media_type: Optional[Union[MediaType, str]] = None,
         middleware: Optional[List[Middleware]] = None,
         name: Optional[str] = None,
         opt: Optional[Dict[str, Any]] = None,
@@ -1146,6 +1209,7 @@ class put(HTTPRouteHandler):
         security: Optional[List[SecurityRequirement]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
+        type_encoders: Optional["TypeEncodersMap"] = None,
         **kwargs: Any,
     ) -> None:
         """Initialize `put`
@@ -1203,6 +1267,7 @@ class put(HTTPRouteHandler):
             security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
             tags: A list of string tags that will be appended to the OpenAPI schema.
+            type_encoders: A mapping of types to callables that transform them into types supported for serialization.
             **kwargs: Any additional kwarg - will be set in the opt dictionary.
         """
         if "http_method" in kwargs:
@@ -1242,6 +1307,7 @@ class put(HTTPRouteHandler):
             summary=summary,
             sync_to_thread=sync_to_thread,
             tags=tags,
+            type_encoders=type_encoders,
             **kwargs,
         )
 
@@ -1268,7 +1334,7 @@ class patch(HTTPRouteHandler):
         etag: Optional[ETag] = None,
         exception_handlers: Optional[ExceptionHandlersMap] = None,
         guards: Optional[List[Guard]] = None,
-        media_type: Union[MediaType, str] = MediaType.JSON,
+        media_type: Optional[Union[MediaType, str]] = None,
         middleware: Optional[List[Middleware]] = None,
         name: Optional[str] = None,
         opt: Optional[Dict[str, Any]] = None,
@@ -1290,6 +1356,7 @@ class patch(HTTPRouteHandler):
         security: Optional[List[SecurityRequirement]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
+        type_encoders: Optional["TypeEncodersMap"] = None,
         **kwargs: Any,
     ) -> None:
         """Initialize `patch`.
@@ -1347,6 +1414,7 @@ class patch(HTTPRouteHandler):
             security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
             tags: A list of string tags that will be appended to the OpenAPI schema.
+            type_encoders: A mapping of types to callables that transform them into types supported for serialization.
             **kwargs: Any additional kwarg - will be set in the opt dictionary.
         """
         if "http_method" in kwargs:
@@ -1386,6 +1454,7 @@ class patch(HTTPRouteHandler):
             summary=summary,
             sync_to_thread=sync_to_thread,
             tags=tags,
+            type_encoders=type_encoders,
             **kwargs,
         )
 
@@ -1412,7 +1481,7 @@ class delete(HTTPRouteHandler):
         etag: Optional[ETag] = None,
         exception_handlers: Optional[ExceptionHandlersMap] = None,
         guards: Optional[List[Guard]] = None,
-        media_type: Union[MediaType, str] = MediaType.JSON,
+        media_type: Optional[Union[MediaType, str]] = None,
         middleware: Optional[List[Middleware]] = None,
         name: Optional[str] = None,
         opt: Optional[Dict[str, Any]] = None,
@@ -1434,6 +1503,7 @@ class delete(HTTPRouteHandler):
         security: Optional[List[SecurityRequirement]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
+        type_encoders: Optional["TypeEncodersMap"] = None,
         **kwargs: Any,
     ) -> None:
         """Initialize `delete`
@@ -1491,6 +1561,7 @@ class delete(HTTPRouteHandler):
             security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
             tags: A list of string tags that will be appended to the OpenAPI schema.
+            type_encoders: A mapping of types to callables that transform them into types supported for serialization.
             **kwargs: Any additional kwarg - will be set in the opt dictionary.
         """
         if "http_method" in kwargs:
@@ -1530,5 +1601,6 @@ class delete(HTTPRouteHandler):
             summary=summary,
             sync_to_thread=sync_to_thread,
             tags=tags,
+            type_encoders=type_encoders,
             **kwargs,
         )
