@@ -50,8 +50,7 @@ def is_class_and_subclass(value: Any, t_type: Type[T]) -> TypeGuard[Type[T]]:
 
 
 def is_optional_union(annotation: Any) -> bool:
-    """Given a type annotation determine if the annotation infers an optional
-    union.
+    """Given a type annotation determine if the annotation infers an optional union.
 
     Args:
         annotation: A type.
@@ -63,7 +62,7 @@ def is_optional_union(annotation: Any) -> bool:
 
 
 def is_dataclass_class_typeguard(value: Any) -> "TypeGuard[DataclassClass]":
-    """Wrapper for `is_dataclass()` that narrows to type only, not instance.
+    """Wrap `is_dataclass()` in a `TypeGuard`, narrowing to type only, not instance.
 
     Args:
         value: tested to determine if type of `dataclass`.
@@ -75,7 +74,7 @@ def is_dataclass_class_typeguard(value: Any) -> "TypeGuard[DataclassClass]":
 
 
 def is_dataclass_class_or_instance_typeguard(value: Any) -> "TypeGuard[DataclassClassOrInstance]":
-    """Wrapper for `is_dataclass()` that narrows type.
+    """Wrap `is_dataclass()` in a `TypeGuard`.
 
     Args:
         value: tested to determine if instance or type of `dataclass`.
@@ -87,7 +86,7 @@ def is_dataclass_class_or_instance_typeguard(value: Any) -> "TypeGuard[Dataclass
 
 
 def is_typeddict_typeguard(value: Any) -> "TypeGuard[TypedDictClass]":
-    """Wrapper for `is_typeddict()` that narrows type.
+    """Wrap `is_typeddict()` in a `TypeGuard`.
 
     Args:
         value: tested to determine if instance or type of `dataclass`.
